from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from nebius.api.nebius import annotations_pb2 as _annotations_pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as _metadata_pb2
from nebius.api.nebius.vpc.v1 import pool_pb2 as _pool_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Allocation(_message.Message):
    __slots__ = ["metadata", "spec", "status"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.ResourceMetadata
    spec: AllocationSpec
    status: AllocationStatus
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[AllocationSpec, _Mapping]] = ..., status: _Optional[_Union[AllocationStatus, _Mapping]] = ...) -> None: ...

class AllocationSpec(_message.Message):
    __slots__ = ["ipv4_private", "ipv4_public"]
    IPV4_PRIVATE_FIELD_NUMBER: _ClassVar[int]
    IPV4_PUBLIC_FIELD_NUMBER: _ClassVar[int]
    ipv4_private: IPv4PrivateAllocationSpec
    ipv4_public: IPv4PublicAllocationSpec
    def __init__(self, ipv4_private: _Optional[_Union[IPv4PrivateAllocationSpec, _Mapping]] = ..., ipv4_public: _Optional[_Union[IPv4PublicAllocationSpec, _Mapping]] = ...) -> None: ...

class IPv4PrivateAllocationSpec(_message.Message):
    __slots__ = ["cidr", "subnet_id", "pool_id"]
    CIDR_FIELD_NUMBER: _ClassVar[int]
    SUBNET_ID_FIELD_NUMBER: _ClassVar[int]
    POOL_ID_FIELD_NUMBER: _ClassVar[int]
    cidr: str
    subnet_id: str
    pool_id: str
    def __init__(self, cidr: _Optional[str] = ..., subnet_id: _Optional[str] = ..., pool_id: _Optional[str] = ...) -> None: ...

class IPv4PublicAllocationSpec(_message.Message):
    __slots__ = ["cidr", "subnet_id", "pool_id"]
    CIDR_FIELD_NUMBER: _ClassVar[int]
    SUBNET_ID_FIELD_NUMBER: _ClassVar[int]
    POOL_ID_FIELD_NUMBER: _ClassVar[int]
    cidr: str
    subnet_id: str
    pool_id: str
    def __init__(self, cidr: _Optional[str] = ..., subnet_id: _Optional[str] = ..., pool_id: _Optional[str] = ...) -> None: ...

class AllocationStatus(_message.Message):
    __slots__ = ["state", "details", "assignment", "static"]
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        STATE_UNSPECIFIED: _ClassVar[AllocationStatus.State]
        CREATING: _ClassVar[AllocationStatus.State]
        ALLOCATED: _ClassVar[AllocationStatus.State]
        ASSIGNED: _ClassVar[AllocationStatus.State]
        DELETING: _ClassVar[AllocationStatus.State]
    STATE_UNSPECIFIED: AllocationStatus.State
    CREATING: AllocationStatus.State
    ALLOCATED: AllocationStatus.State
    ASSIGNED: AllocationStatus.State
    DELETING: AllocationStatus.State
    STATE_FIELD_NUMBER: _ClassVar[int]
    DETAILS_FIELD_NUMBER: _ClassVar[int]
    ASSIGNMENT_FIELD_NUMBER: _ClassVar[int]
    STATIC_FIELD_NUMBER: _ClassVar[int]
    state: AllocationStatus.State
    details: AllocationDetails
    assignment: Assignment
    static: bool
    def __init__(self, state: _Optional[_Union[AllocationStatus.State, str]] = ..., details: _Optional[_Union[AllocationDetails, _Mapping]] = ..., assignment: _Optional[_Union[Assignment, _Mapping]] = ..., static: bool = ...) -> None: ...

class AllocationDetails(_message.Message):
    __slots__ = ["allocated_cidr", "pool_id", "version", "subnet_id"]
    ALLOCATED_CIDR_FIELD_NUMBER: _ClassVar[int]
    POOL_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    SUBNET_ID_FIELD_NUMBER: _ClassVar[int]
    allocated_cidr: str
    pool_id: str
    version: _pool_pb2.IpVersion
    subnet_id: str
    def __init__(self, allocated_cidr: _Optional[str] = ..., pool_id: _Optional[str] = ..., version: _Optional[_Union[_pool_pb2.IpVersion, str]] = ..., subnet_id: _Optional[str] = ...) -> None: ...

class Assignment(_message.Message):
    __slots__ = ["network_interface", "load_balancer"]
    NETWORK_INTERFACE_FIELD_NUMBER: _ClassVar[int]
    LOAD_BALANCER_FIELD_NUMBER: _ClassVar[int]
    network_interface: NetworkInterfaceAssignment
    load_balancer: LoadBalancerAssignment
    def __init__(self, network_interface: _Optional[_Union[NetworkInterfaceAssignment, _Mapping]] = ..., load_balancer: _Optional[_Union[LoadBalancerAssignment, _Mapping]] = ...) -> None: ...

class NetworkInterfaceAssignment(_message.Message):
    __slots__ = ["instance_id", "name"]
    INSTANCE_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    instance_id: str
    name: str
    def __init__(self, instance_id: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class LoadBalancerAssignment(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19nebius/iam/v1/state.proto\x12\rnebius.iam.v1*\x9e\x02\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x1b\n\x17SCHEDULING_FOR_DELETION\x10\x02\x12\x1a\n\x16SCHEDULED_FOR_DELETION\x10\x03\x12%\n!SCHEDULING_FOR_DELETION_BY_PARENT\x10\x04\x12$\n SCHEDULED_FOR_DELETION_BY_PARENT\x10\x05\x12\x0e\n\nUNDELETING\x10\x06\x12\x0b\n\x07PURGING\x10\x07\x12\n\n\x06PURGED\x10\x08\x12\x0b\n\x07\x43REATED\x10\t\x12\x0e\n\nACTIVATING\x10\n\x12\x0b\n\x07PARKING\x10\x0b\x12\n\n\x06PARKED\x10\x0c\x12\r\n\x08\x43REATING\x10\xe9\x07\x42Q\n\x14\x61i.nebius.pub.iam.v1B\nStateProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\nStateProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _globals['_STATE']._serialized_start=45
  _globals['_STATE']._serialized_end=331
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/maintenance/v1alpha1/maintenance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-nebius/maintenance/v1alpha1/maintenance.proto\x12\x1bnebius.maintenance.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe7\x01\n\x0bMaintenance\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12H\n\x04spec\x18\x02 \x01(\x0b\x32,.nebius.maintenance.v1alpha1.MaintenanceSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12\x46\n\x06status\x18\x03 \x01(\x0b\x32..nebius.maintenance.v1alpha1.MaintenanceStatusR\x06status\"X\n\x0fMaintenanceSpec\x12\x45\n\x0cscheduled_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\x0bscheduledAt\"\xc9\x02\n\x11MaintenanceStatus\x12T\n\x12\x61\x66\x66\x65\x63ted_resources\x18\x01 \x03(\x0b\x32%.nebius.maintenance.v1alpha1.ResourceR\x11\x61\x66\x66\x65\x63tedResources\x12\x39\n\nstarted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartedAt\x12;\n\x0b\x66inished_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nfinishedAt\x12@\n\x05state\x18\x04 \x01(\x0e\x32\".nebius.maintenance.v1alpha1.StateB\x06\xbaH\x03\xc8\x01\x01R\x05state\x12$\n\rreschedulable\x18\x05 \x01(\x08R\rreschedulable\"G\n\x08Resource\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\x12#\n\tparent_id\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId*\x84\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x13\n\x0fSTATE_SCHEDULED\x10\x01\x12\x15\n\x11STATE_IN_PROGRESS\x10\x02\x12\x12\n\x0eSTATE_FINISHED\x10\x03\x12\x0f\n\x0bSTATE_ERROR\x10\x04\x12\x13\n\x0fSTATE_CANCELLED\x10\x05\x42s\n\"ai.nebius.pub.maintenance.v1alpha1B\x10MaintenanceProtoP\x01Z9github.com/nebius/gosdk/proto/nebius/maintenance/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.maintenance.v1alpha1.maintenance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"ai.nebius.pub.maintenance.v1alpha1B\020MaintenanceProtoP\001Z9github.com/nebius/gosdk/proto/nebius/maintenance/v1alpha1'
  _MAINTENANCE.fields_by_name['metadata']._options = None
  _MAINTENANCE.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _MAINTENANCE.fields_by_name['spec']._options = None
  _MAINTENANCE.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _MAINTENANCESPEC.fields_by_name['scheduled_at']._options = None
  _MAINTENANCESPEC.fields_by_name['scheduled_at']._serialized_options = b'\272H\003\310\001\001'
  _MAINTENANCESTATUS.fields_by_name['state']._options = None
  _MAINTENANCESTATUS.fields_by_name['state']._serialized_options = b'\272H\003\310\001\001'
  _RESOURCE.fields_by_name['id']._options = None
  _RESOURCE.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _RESOURCE.fields_by_name['parent_id']._options = None
  _RESOURCE.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_STATE']._serialized_start=903
  _globals['_STATE']._serialized_end=1035
  _globals['_MAINTENANCE']._serialized_start=174
  _globals['_MAINTENANCE']._serialized_end=405
  _globals['_MAINTENANCESPEC']._serialized_start=407
  _globals['_MAINTENANCESPEC']._serialized_end=495
  _globals['_MAINTENANCESTATUS']._serialized_start=498
  _globals['_MAINTENANCESTATUS']._serialized_end=827
  _globals['_RESOURCE']._serialized_start=829
  _globals['_RESOURCE']._serialized_end=900
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from nebius.api.nebius.logging.v1.agentmanager import version_service_pb2 as nebius_dot_logging_dot_v1_dot_agentmanager_dot_version__service__pb2


class VersionServiceStub(object):
    """VersionService provides functionality for managing nebius-observability-agent versions and health status
    in the Nebius observability system.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetVersion = channel.unary_unary(
                '/nebius.logging.agentmanager.v1.VersionService/GetVersion',
                request_serializer=nebius_dot_logging_dot_v1_dot_agentmanager_dot_version__service__pb2.GetVersionRequest.SerializeToString,
                response_deserializer=nebius_dot_logging_dot_v1_dot_agentmanager_dot_version__service__pb2.GetVersionResponse.FromString,
                )


class VersionServiceServicer(object):
    """VersionService provides functionality for managing nebius-observability-agent versions and health status
    in the Nebius observability system.
    """

    def GetVersion(self, request, context):
        """GetVersion retrieves version information and receives instructions for agent updates
        or maintenance based on the current state and health of the agent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VersionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVersion,
                    request_deserializer=nebius_dot_logging_dot_v1_dot_agentmanager_dot_version__service__pb2.GetVersionRequest.FromString,
                    response_serializer=nebius_dot_logging_dot_v1_dot_agentmanager_dot_version__service__pb2.GetVersionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nebius.logging.agentmanager.v1.VersionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class VersionService(object):
    """VersionService provides functionality for managing nebius-observability-agent versions and health status
    in the Nebius observability system.
    """

    @staticmethod
    def GetVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.logging.agentmanager.v1.VersionService/GetVersion',
            nebius_dot_logging_dot_v1_dot_agentmanager_dot_version__service__pb2.GetVersionRequest.SerializeToString,
            nebius_dot_logging_dot_v1_dot_agentmanager_dot_version__service__pb2.GetVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/vpc/v1alpha1/subnet_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.vpc.v1alpha1 import subnet_pb2 as nebius_dot_vpc_dot_v1alpha1_dot_subnet__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(nebius/vpc/v1alpha1/subnet_service.proto\x12\x13nebius.vpc.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a nebius/vpc/v1alpha1/subnet.proto\"*\n\x10GetSubnetRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"Y\n\x16GetSubnetByNameRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1a\n\x04name\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\"\x8d\x01\n\x12ListSubnetsRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\"\x98\x01\n\x1bListSubnetsByNetworkRequest\x12%\n\nnetwork_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\tnetworkId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\"p\n\x13ListSubnetsResponse\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\x1b.nebius.vpc.v1alpha1.SubnetR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\x81\x03\n\rSubnetService\x12I\n\x03Get\x12%.nebius.vpc.v1alpha1.GetSubnetRequest\x1a\x1b.nebius.vpc.v1alpha1.Subnet\x12U\n\tGetByName\x12+.nebius.vpc.v1alpha1.GetSubnetByNameRequest\x1a\x1b.nebius.vpc.v1alpha1.Subnet\x12Y\n\x04List\x12\'.nebius.vpc.v1alpha1.ListSubnetsRequest\x1a(.nebius.vpc.v1alpha1.ListSubnetsResponse\x12k\n\rListByNetwork\x12\x30.nebius.vpc.v1alpha1.ListSubnetsByNetworkRequest\x1a(.nebius.vpc.v1alpha1.ListSubnetsResponse\x1a\x06\xbaJ\x03vpcBe\n\x1a\x61i.nebius.pub.vpc.v1alpha1B\x12SubnetServiceProtoP\x01Z1github.com/nebius/gosdk/proto/nebius/vpc/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.vpc.v1alpha1.subnet_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032ai.nebius.pub.vpc.v1alpha1B\022SubnetServiceProtoP\001Z1github.com/nebius/gosdk/proto/nebius/vpc/v1alpha1'
  _GETSUBNETREQUEST.fields_by_name['id']._options = None
  _GETSUBNETREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _GETSUBNETBYNAMEREQUEST.fields_by_name['parent_id']._options = None
  _GETSUBNETBYNAMEREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _GETSUBNETBYNAMEREQUEST.fields_by_name['name']._options = None
  _GETSUBNETBYNAMEREQUEST.fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _LISTSUBNETSREQUEST.fields_by_name['parent_id']._options = None
  _LISTSUBNETSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _LISTSUBNETSBYNETWORKREQUEST.fields_by_name['network_id']._options = None
  _LISTSUBNETSBYNETWORKREQUEST.fields_by_name['network_id']._serialized_options = b'\272H\003\310\001\001'
  _SUBNETSERVICE._options = None
  _SUBNETSERVICE._serialized_options = b'\272J\003vpc'
  _globals['_GETSUBNETREQUEST']._serialized_start=154
  _globals['_GETSUBNETREQUEST']._serialized_end=196
  _globals['_GETSUBNETBYNAMEREQUEST']._serialized_start=198
  _globals['_GETSUBNETBYNAMEREQUEST']._serialized_end=287
  _globals['_LISTSUBNETSREQUEST']._serialized_start=290
  _globals['_LISTSUBNETSREQUEST']._serialized_end=431
  _globals['_LISTSUBNETSBYNETWORKREQUEST']._serialized_start=434
  _globals['_LISTSUBNETSBYNETWORKREQUEST']._serialized_end=586
  _globals['_LISTSUBNETSRESPONSE']._serialized_start=588
  _globals['_LISTSUBNETSRESPONSE']._serialized_end=700
  _globals['_SUBNETSERVICE']._serialized_start=703
  _globals['_SUBNETSERVICE']._serialized_end=1088
# @@protoc_insertion_point(module_scope)



from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as _metadata_pb2
from nebius.api.nebius import annotations_pb2 as _annotations_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Filesystem(_message.Message):
    __slots__ = ["metadata", "spec", "status"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.ResourceMetadata
    spec: FilesystemSpec
    status: FilesystemStatus
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[FilesystemSpec, _Mapping]] = ..., status: _Optional[_Union[FilesystemStatus, _Mapping]] = ...) -> None: ...

class FilesystemSpec(_message.Message):
    __slots__ = ["size_bytes", "size_kibibytes", "size_mebibytes", "size_gibibytes", "block_size_bytes", "type"]
    class FilesystemType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        UNSPECIFIED: _ClassVar[FilesystemSpec.FilesystemType]
        NETWORK_SSD: _ClassVar[FilesystemSpec.FilesystemType]
        NETWORK_HDD: _ClassVar[FilesystemSpec.FilesystemType]
        WEKA: _ClassVar[FilesystemSpec.FilesystemType]
        VAST: _ClassVar[FilesystemSpec.FilesystemType]
    UNSPECIFIED: FilesystemSpec.FilesystemType
    NETWORK_SSD: FilesystemSpec.FilesystemType
    NETWORK_HDD: FilesystemSpec.FilesystemType
    WEKA: FilesystemSpec.FilesystemType
    VAST: FilesystemSpec.FilesystemType
    SIZE_BYTES_FIELD_NUMBER: _ClassVar[int]
    SIZE_KIBIBYTES_FIELD_NUMBER: _ClassVar[int]
    SIZE_MEBIBYTES_FIELD_NUMBER: _ClassVar[int]
    SIZE_GIBIBYTES_FIELD_NUMBER: _ClassVar[int]
    BLOCK_SIZE_BYTES_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    size_bytes: int
    size_kibibytes: int
    size_mebibytes: int
    size_gibibytes: int
    block_size_bytes: int
    type: FilesystemSpec.FilesystemType
    def __init__(self, size_bytes: _Optional[int] = ..., size_kibibytes: _Optional[int] = ..., size_mebibytes: _Optional[int] = ..., size_gibibytes: _Optional[int] = ..., block_size_bytes: _Optional[int] = ..., type: _Optional[_Union[FilesystemSpec.FilesystemType, str]] = ...) -> None: ...

class FilesystemStatus(_message.Message):
    __slots__ = ["state", "state_description", "read_write_attachments", "read_only_attachments", "size_bytes", "reconciling", "block_size_bytes"]
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        UNSPECIFIED: _ClassVar[FilesystemStatus.State]
        CREATING: _ClassVar[FilesystemStatus.State]
        READY: _ClassVar[FilesystemStatus.State]
        UPDATING: _ClassVar[FilesystemStatus.State]
        DELETING: _ClassVar[FilesystemStatus.State]
        ERROR: _ClassVar[FilesystemStatus.State]
    UNSPECIFIED: FilesystemStatus.State
    CREATING: FilesystemStatus.State
    READY: FilesystemStatus.State
    UPDATING: FilesystemStatus.State
    DELETING: FilesystemStatus.State
    ERROR: FilesystemStatus.State
    STATE_FIELD_NUMBER: _ClassVar[int]
    STATE_DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    READ_WRITE_ATTACHMENTS_FIELD_NUMBER: _ClassVar[int]
    READ_ONLY_ATTACHMENTS_FIELD_NUMBER: _ClassVar[int]
    SIZE_BYTES_FIELD_NUMBER: _ClassVar[int]
    RECONCILING_FIELD_NUMBER: _ClassVar[int]
    BLOCK_SIZE_BYTES_FIELD_NUMBER: _ClassVar[int]
    state: FilesystemStatus.State
    state_description: str
    read_write_attachments: _containers.RepeatedScalarFieldContainer[str]
    read_only_attachments: _containers.RepeatedScalarFieldContainer[str]
    size_bytes: int
    reconciling: bool
    block_size_bytes: int
    def __init__(self, state: _Optional[_Union[FilesystemStatus.State, str]] = ..., state_description: _Optional[str] = ..., read_write_attachments: _Optional[_Iterable[str]] = ..., read_only_attachments: _Optional[_Iterable[str]] = ..., size_bytes: _Optional[int] = ..., reconciling: bool = ..., block_size_bytes: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/federated_credentials.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)nebius/iam/v1/federated_credentials.proto\x12\rnebius.iam.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\"\xec\x01\n\x14\x46\x65\x64\x65ratedCredentials\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x43\n\x04spec\x18\x02 \x01(\x0b\x32\'.nebius.iam.v1.FederatedCredentialsSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12G\n\x06status\x18\x03 \x01(\x0b\x32).nebius.iam.v1.FederatedCredentialsStatusB\x04\xbaJ\x01\x05R\x06status\"\xe9\x01\n\x18\x46\x65\x64\x65ratedCredentialsSpec\x12M\n\roidc_provider\x18\x01 \x01(\x0b\x32&.nebius.iam.v1.OidcCredentialsProviderH\x00R\x0coidcProvider\x12\x38\n\x14\x66\x65\x64\x65rated_subject_id\x18\x65 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x12\x66\x65\x64\x65ratedSubjectId\x12%\n\nsubject_id\x18o \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\tsubjectIdB\x1d\n\x14\x63redentials_provider\x12\x05\xbaH\x02\x08\x01\"b\n\x17OidcCredentialsProvider\x12%\n\nissuer_url\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\tissuerUrl\x12 \n\x0cjwk_set_json\x18\x02 \x01(\tR\njwkSetJson\"\x1c\n\x1a\x46\x65\x64\x65ratedCredentialsStatusB`\n\x14\x61i.nebius.pub.iam.v1B\x19\x46\x65\x64\x65ratedCredentialsProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.federated_credentials_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\031FederatedCredentialsProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _FEDERATEDCREDENTIALS.fields_by_name['metadata']._options = None
  _FEDERATEDCREDENTIALS.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _FEDERATEDCREDENTIALS.fields_by_name['spec']._options = None
  _FEDERATEDCREDENTIALS.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _FEDERATEDCREDENTIALS.fields_by_name['status']._options = None
  _FEDERATEDCREDENTIALS.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _FEDERATEDCREDENTIALSSPEC.oneofs_by_name['credentials_provider']._options = None
  _FEDERATEDCREDENTIALSSPEC.oneofs_by_name['credentials_provider']._serialized_options = b'\272H\002\010\001'
  _FEDERATEDCREDENTIALSSPEC.fields_by_name['federated_subject_id']._options = None
  _FEDERATEDCREDENTIALSSPEC.fields_by_name['federated_subject_id']._serialized_options = b'\272H\003\310\001\001'
  _FEDERATEDCREDENTIALSSPEC.fields_by_name['subject_id']._options = None
  _FEDERATEDCREDENTIALSSPEC.fields_by_name['subject_id']._serialized_options = b'\272H\003\310\001\001'
  _OIDCCREDENTIALSPROVIDER.fields_by_name['issuer_url']._options = None
  _OIDCCREDENTIALSPROVIDER.fields_by_name['issuer_url']._serialized_options = b'\272H\003\310\001\001'
  _globals['_FEDERATEDCREDENTIALS']._serialized_start=149
  _globals['_FEDERATEDCREDENTIALS']._serialized_end=385
  _globals['_FEDERATEDCREDENTIALSSPEC']._serialized_start=388
  _globals['_FEDERATEDCREDENTIALSSPEC']._serialized_end=621
  _globals['_OIDCCREDENTIALSPROVIDER']._serialized_start=623
  _globals['_OIDCCREDENTIALSPROVIDER']._serialized_end=721
  _globals['_FEDERATEDCREDENTIALSSTATUS']._serialized_start=723
  _globals['_FEDERATEDCREDENTIALSSTATUS']._serialized_end=751
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.storage.v1 import bucket_pb2 as nebius_dot_storage_dot_v1_dot_bucket__pb2
from nebius.api.nebius.storage.v1 import bucket_service_pb2 as nebius_dot_storage_dot_v1_dot_bucket__service__pb2


class BucketServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/nebius.storage.v1.BucketService/Get',
                request_serializer=nebius_dot_storage_dot_v1_dot_bucket__service__pb2.GetBucketRequest.SerializeToString,
                response_deserializer=nebius_dot_storage_dot_v1_dot_bucket__pb2.Bucket.FromString,
                )
        self.GetByName = channel.unary_unary(
                '/nebius.storage.v1.BucketService/GetByName',
                request_serializer=nebius_dot_storage_dot_v1_dot_bucket__service__pb2.GetBucketByNameRequest.SerializeToString,
                response_deserializer=nebius_dot_storage_dot_v1_dot_bucket__pb2.Bucket.FromString,
                )
        self.List = channel.unary_unary(
                '/nebius.storage.v1.BucketService/List',
                request_serializer=nebius_dot_storage_dot_v1_dot_bucket__service__pb2.ListBucketsRequest.SerializeToString,
                response_deserializer=nebius_dot_storage_dot_v1_dot_bucket__service__pb2.ListBucketsResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/nebius.storage.v1.BucketService/Create',
                request_serializer=nebius_dot_storage_dot_v1_dot_bucket__service__pb2.CreateBucketRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/nebius.storage.v1.BucketService/Update',
                request_serializer=nebius_dot_storage_dot_v1_dot_bucket__service__pb2.UpdateBucketRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/nebius.storage.v1.BucketService/Delete',
                request_serializer=nebius_dot_storage_dot_v1_dot_bucket__service__pb2.DeleteBucketRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Purge = channel.unary_unary(
                '/nebius.storage.v1.BucketService/Purge',
                request_serializer=nebius_dot_storage_dot_v1_dot_bucket__service__pb2.PurgeBucketRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Undelete = channel.unary_unary(
                '/nebius.storage.v1.BucketService/Undelete',
                request_serializer=nebius_dot_storage_dot_v1_dot_bucket__service__pb2.UndeleteBucketRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )


class BucketServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Purge(self, request, context):
        """Purge instantly deletes the bucket in ScheduledForDeletion state.
        It can be used only for buckets in ScheduledForDeletion state.
        If you want to delete Active bucket instantly, use Delete with zero ttl.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Undelete(self, request, context):
        """Undelete recovers the bucket from ScheduledForDeletion state to Active.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BucketServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=nebius_dot_storage_dot_v1_dot_bucket__service__pb2.GetBucketRequest.FromString,
                    response_serializer=nebius_dot_storage_dot_v1_dot_bucket__pb2.Bucket.SerializeToString,
            ),
            'GetByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetByName,
                    request_deserializer=nebius_dot_storage_dot_v1_dot_bucket__service__pb2.GetBucketByNameRequest.FromString,
                    response_serializer=nebius_dot_storage_dot_v1_dot_bucket__pb2.Bucket.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=nebius_dot_storage_dot_v1_dot_bucket__service__pb2.ListBucketsRequest.FromString,
                    response_serializer=nebius_dot_storage_dot_v1_dot_bucket__service__pb2.ListBucketsResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=nebius_dot_storage_dot_v1_dot_bucket__service__pb2.CreateBucketRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=nebius_dot_storage_dot_v1_dot_bucket__service__pb2.UpdateBucketRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=nebius_dot_storage_dot_v1_dot_bucket__service__pb2.DeleteBucketRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Purge': grpc.unary_unary_rpc_method_handler(
                    servicer.Purge,
                    request_deserializer=nebius_dot_storage_dot_v1_dot_bucket__service__pb2.PurgeBucketRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Undelete': grpc.unary_unary_rpc_method_handler(
                    servicer.Undelete,
                    request_deserializer=nebius_dot_storage_dot_v1_dot_bucket__service__pb2.UndeleteBucketRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nebius.storage.v1.BucketService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class BucketService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.storage.v1.BucketService/Get',
            nebius_dot_storage_dot_v1_dot_bucket__service__pb2.GetBucketRequest.SerializeToString,
            nebius_dot_storage_dot_v1_dot_bucket__pb2.Bucket.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.storage.v1.BucketService/GetByName',
            nebius_dot_storage_dot_v1_dot_bucket__service__pb2.GetBucketByNameRequest.SerializeToString,
            nebius_dot_storage_dot_v1_dot_bucket__pb2.Bucket.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.storage.v1.BucketService/List',
            nebius_dot_storage_dot_v1_dot_bucket__service__pb2.ListBucketsRequest.SerializeToString,
            nebius_dot_storage_dot_v1_dot_bucket__service__pb2.ListBucketsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.storage.v1.BucketService/Create',
            nebius_dot_storage_dot_v1_dot_bucket__service__pb2.CreateBucketRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.storage.v1.BucketService/Update',
            nebius_dot_storage_dot_v1_dot_bucket__service__pb2.UpdateBucketRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.storage.v1.BucketService/Delete',
            nebius_dot_storage_dot_v1_dot_bucket__service__pb2.DeleteBucketRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Purge(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.storage.v1.BucketService/Purge',
            nebius_dot_storage_dot_v1_dot_bucket__service__pb2.PurgeBucketRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Undelete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.storage.v1.BucketService/Undelete',
            nebius_dot_storage_dot_v1_dot_bucket__service__pb2.UndeleteBucketRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/annotations.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18nebius/annotations.proto\x12\x06nebius\x1a google/protobuf/descriptor.proto\"*\n\x14ServicePySDKSettings\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\")\n\x13MethodPySDKSettings\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\"(\n\x12\x46ieldPySDKSettings\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\"*\n\x14MessagePySDKSettings\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\"(\n\x12OneofPySDKSettings\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\"\'\n\x11\x45numPySDKSettings\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\",\n\x16\x45numValuePySDKSettings\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\"Y\n\x12\x44\x65precationDetails\x12!\n\x0c\x65\x66\x66\x65\x63tive_at\x18\x01 \x01(\tR\x0b\x65\x66\x66\x65\x63tiveAt\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\"W\n\x10NIDFieldSettings\x12\x1a\n\x08resource\x18\x01 \x03(\tR\x08resource\x12\'\n\x0fparent_resource\x18\x02 \x03(\tR\x0eparentResource*c\n\x10ResourceBehavior\x12!\n\x1dRESOURCE_BEHAVIOR_UNSPECIFIED\x10\x00\x12\x0b\n\x07MOVABLE\x10\x01\x12\x0b\n\x07UNNAMED\x10\x02\x12\x12\n\x0eIMMUTABLE_NAME\x10\x03*\xa2\x01\n\rFieldBehavior\x12\x1e\n\x1a\x46IELD_BEHAVIOR_UNSPECIFIED\x10\x00\x12\r\n\tIMMUTABLE\x10\x02\x12\x0e\n\nIDENTIFIER\x10\x03\x12\x0e\n\nINPUT_ONLY\x10\x04\x12\x0f\n\x0bOUTPUT_ONLY\x10\x05\x12\x1a\n\x16MEANINGFUL_EMPTY_VALUE\x10\x06\x12\x15\n\x11NON_EMPTY_DEFAULT\x10\x07:s\n\x18\x66ile_deprecation_details\x12\x1c.google.protobuf.FileOptions\x18\xaa\t \x01(\x0b\x32\x1a.nebius.DeprecationDetailsR\x16\x66ileDeprecationDetails:J\n\x10\x61pi_service_name\x12\x1f.google.protobuf.ServiceOptions\x18\xa7\t \x01(\tR\x0e\x61piServiceName:|\n\x1bservice_deprecation_details\x12\x1f.google.protobuf.ServiceOptions\x18\xaa\t \x01(\x0b\x32\x1a.nebius.DeprecationDetailsR\x19serviceDeprecationDetails:d\n\x0eservice_py_sdk\x12\x1f.google.protobuf.ServiceOptions\x18\xab\t \x01(\x0b\x32\x1c.nebius.ServicePySDKSettingsR\x0cservicePySdk:y\n\x1amethod_deprecation_details\x12\x1e.google.protobuf.MethodOptions\x18\xaa\t \x01(\x0b\x32\x1a.nebius.DeprecationDetailsR\x18methodDeprecationDetails:`\n\rmethod_py_sdk\x12\x1e.google.protobuf.MethodOptions\x18\xab\t \x01(\x0b\x32\x1b.nebius.MethodPySDKSettingsR\x0bmethodPySdk:g\n\x11resource_behavior\x12\x1f.google.protobuf.MessageOptions\x18\xa7\t \x03(\x0e\x32\x18.nebius.ResourceBehaviorR\x10resourceBehavior:|\n\x1bmessage_deprecation_details\x12\x1f.google.protobuf.MessageOptions\x18\xaa\t \x01(\x0b\x32\x1a.nebius.DeprecationDetailsR\x19messageDeprecationDetails:d\n\x0emessage_py_sdk\x12\x1f.google.protobuf.MessageOptions\x18\xab\t \x01(\x0b\x32\x1c.nebius.MessagePySDKSettingsR\x0cmessagePySdk:\\\n\x0e\x66ield_behavior\x12\x1d.google.protobuf.FieldOptions\x18\xa7\t \x03(\x0e\x32\x15.nebius.FieldBehaviorR\rfieldBehavior:<\n\tsensitive\x12\x1d.google.protobuf.FieldOptions\x18\xa8\t \x01(\x08R\tsensitive:@\n\x0b\x63redentials\x12\x1d.google.protobuf.FieldOptions\x18\xa9\t \x01(\x08R\x0b\x63redentials:v\n\x19\x66ield_deprecation_details\x12\x1d.google.protobuf.FieldOptions\x18\xaa\t \x01(\x0b\x32\x1a.nebius.DeprecationDetailsR\x17\x66ieldDeprecationDetails:\\\n\x0c\x66ield_py_sdk\x12\x1d.google.protobuf.FieldOptions\x18\xab\t \x01(\x0b\x32\x1a.nebius.FieldPySDKSettingsR\nfieldPySdk:J\n\x03nid\x12\x1d.google.protobuf.FieldOptions\x18\xac\t \x01(\x0b\x32\x18.nebius.NIDFieldSettingsR\x03nid:\\\n\x0eoneof_behavior\x12\x1d.google.protobuf.OneofOptions\x18\xa7\t \x03(\x0e\x32\x15.nebius.FieldBehaviorR\roneofBehavior:\\\n\x0coneof_py_sdk\x12\x1d.google.protobuf.OneofOptions\x18\xa8\t \x01(\x0b\x32\x1a.nebius.OneofPySDKSettingsR\noneofPySdk:X\n\x0b\x65num_py_sdk\x12\x1c.google.protobuf.EnumOptions\x18\xa7\t \x01(\x0b\x32\x19.nebius.EnumPySDKSettingsR\tenumPySdk:s\n\x18\x65num_deprecation_details\x12\x1c.google.protobuf.EnumOptions\x18\xaa\t \x01(\x0b\x32\x1a.nebius.DeprecationDetailsR\x16\x65numDeprecationDetails:\x83\x01\n\x1e\x65num_value_deprecation_details\x12!.google.protobuf.EnumValueOptions\x18\xaa\t \x01(\x0b\x32\x1a.nebius.DeprecationDetailsR\x1b\x65numValueDeprecationDetails:m\n\x11\x65num_value_py_sdk\x12!.google.protobuf.EnumValueOptions\x18\xab\t \x01(\x0b\x32\x1e.nebius.EnumValuePySDKSettingsR\x0e\x65numValuePySdkBI\n\rai.nebius.pubB\x10\x41nnotationsProtoP\x01Z$github.com/nebius/gosdk/proto/nebiusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.annotations_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(file_deprecation_details)
  google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(api_service_name)
  google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(service_deprecation_details)
  google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(service_py_sdk)
  google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(method_deprecation_details)
  google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(method_py_sdk)
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(resource_behavior)
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(message_deprecation_details)
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(message_py_sdk)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(field_behavior)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(sensitive)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(credentials)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(field_deprecation_details)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(field_py_sdk)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(nid)
  google_dot_protobuf_dot_descriptor__pb2.OneofOptions.RegisterExtension(oneof_behavior)
  google_dot_protobuf_dot_descriptor__pb2.OneofOptions.RegisterExtension(oneof_py_sdk)
  google_dot_protobuf_dot_descriptor__pb2.EnumOptions.RegisterExtension(enum_py_sdk)
  google_dot_protobuf_dot_descriptor__pb2.EnumOptions.RegisterExtension(enum_deprecation_details)
  google_dot_protobuf_dot_descriptor__pb2.EnumValueOptions.RegisterExtension(enum_value_deprecation_details)
  google_dot_protobuf_dot_descriptor__pb2.EnumValueOptions.RegisterExtension(enum_value_py_sdk)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\rai.nebius.pubB\020AnnotationsProtoP\001Z$github.com/nebius/gosdk/proto/nebius'
  _globals['_RESOURCEBEHAVIOR']._serialized_start=552
  _globals['_RESOURCEBEHAVIOR']._serialized_end=651
  _globals['_FIELDBEHAVIOR']._serialized_start=654
  _globals['_FIELDBEHAVIOR']._serialized_end=816
  _globals['_SERVICEPYSDKSETTINGS']._serialized_start=70
  _globals['_SERVICEPYSDKSETTINGS']._serialized_end=112
  _globals['_METHODPYSDKSETTINGS']._serialized_start=114
  _globals['_METHODPYSDKSETTINGS']._serialized_end=155
  _globals['_FIELDPYSDKSETTINGS']._serialized_start=157
  _globals['_FIELDPYSDKSETTINGS']._serialized_end=197
  _globals['_MESSAGEPYSDKSETTINGS']._serialized_start=199
  _globals['_MESSAGEPYSDKSETTINGS']._serialized_end=241
  _globals['_ONEOFPYSDKSETTINGS']._serialized_start=243
  _globals['_ONEOFPYSDKSETTINGS']._serialized_end=283
  _globals['_ENUMPYSDKSETTINGS']._serialized_start=285
  _globals['_ENUMPYSDKSETTINGS']._serialized_end=324
  _globals['_ENUMVALUEPYSDKSETTINGS']._serialized_start=326
  _globals['_ENUMVALUEPYSDKSETTINGS']._serialized_end=370
  _globals['_DEPRECATIONDETAILS']._serialized_start=372
  _globals['_DEPRECATIONDETAILS']._serialized_end=461
  _globals['_NIDFIELDSETTINGS']._serialized_start=463
  _globals['_NIDFIELDSETTINGS']._serialized_end=550
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/audit/v2/resource.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.audit.v2 import resource_metadata_pb2 as nebius_dot_audit_dot_v2_dot_resource__metadata__pb2
from nebius.api.nebius.audit.v2 import resource_state_pb2 as nebius_dot_audit_dot_v2_dot_resource__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1enebius/audit/v2/resource.proto\x12\x0fnebius.audit.v2\x1a\x1b\x62uf/validate/validate.proto\x1a\'nebius/audit/v2/resource_metadata.proto\x1a$nebius/audit/v2/resource_state.proto\"\xc8\x01\n\x08Resource\x12\x45\n\x08metadata\x18\x01 \x01(\x0b\x32!.nebius.audit.v2.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x34\n\x05state\x18\x02 \x01(\x0b\x32\x1e.nebius.audit.v2.ResourceStateR\x05state\x12?\n\thierarchy\x18\x03 \x03(\x0b\x32!.nebius.audit.v2.ResourceMetadataR\thierarchyBX\n\x16\x61i.nebius.pub.audit.v2B\rResourceProtoP\x01Z-github.com/nebius/gosdk/proto/nebius/audit/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.audit.v2.resource_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ai.nebius.pub.audit.v2B\rResourceProtoP\001Z-github.com/nebius/gosdk/proto/nebius/audit/v2'
  _RESOURCE.fields_by_name['metadata']._options = None
  _RESOURCE.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _globals['_RESOURCE']._serialized_start=160
  _globals['_RESOURCE']._serialized_end=360
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/vpc/v1alpha1/pool.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1enebius/vpc/v1alpha1/pool.proto\x12\x13nebius.vpc.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a\x18nebius/annotations.proto\"\xb2\x01\n\x04Pool\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x31\n\x04spec\x18\x02 \x01(\x0b\x32\x1d.nebius.vpc.v1alpha1.PoolSpecR\x04spec\x12\x37\n\x06status\x18\x03 \x01(\x0b\x32\x1f.nebius.vpc.v1alpha1.PoolStatusR\x06status\"\xf4\x01\n\x08PoolSpec\x12,\n\x0esource_pool_id\x18\x01 \x01(\tB\x04\xbaJ\x01\x02H\x00R\x0csourcePoolId\x12.\n\x0fsource_scope_id\x18\x02 \x01(\tB\x04\xbaJ\x01\x02H\x00R\rsourceScopeId\x12\x44\n\x07version\x18\x03 \x01(\x0e\x32\x1e.nebius.vpc.v1alpha1.IpVersionB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\x07version\x12\x33\n\x05\x63idrs\x18\x04 \x03(\x0b\x32\x1d.nebius.vpc.v1alpha1.PoolCidrR\x05\x63idrsB\x0f\n\x06source\x12\x05\xbaH\x02\x08\x01\"\x8f\x03\n\x08PoolCidr\x12\x8e\x02\n\x04\x63idr\x18\x01 \x01(\tB\xf9\x01\xbaH\xf5\x01\xba\x01\x9d\x01\n\x11string.valid_cidr\x12.value must be a valid IP address, CIDR or mask\x1aXthis == \'\' || this.matches(\'^/([0-9]|[1-9][0-9]|1[0-2][0-8])$\') || this.isIpPrefix(true)\xba\x01N\n\x0fstring.ip_empty\x12/value is empty, which is not a valid IP address\x1a\nthis != \'\'\xc8\x01\x01R\x04\x63idr\x12@\n\x05state\x18\x02 \x01(\x0e\x32\".nebius.vpc.v1alpha1.PoolCidrStateB\x06\xbaH\x03\xc8\x01\x01R\x05state\x12\x30\n\x0c\x61llowed_mask\x18\x03 \x01(\x03\x42\r\xbaH\n\xc8\x01\x01\"\x05\x18\x80\x01(\x00R\x0b\x61llowedMask\"\xc1\x01\n\nPoolStatus\x12;\n\x05state\x18\x01 \x01(\x0e\x32%.nebius.vpc.v1alpha1.PoolStatus.StateR\x05state\x12\x14\n\x05\x63idrs\x18\x02 \x03(\tR\x05\x63idrs\x12\x19\n\x08scope_id\x18\x03 \x01(\tR\x07scopeId\"E\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03*C\n\rPoolCidrState\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\r\n\tAVAILABLE\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02*;\n\tIpVersion\x12\x1a\n\x16IP_VERSION_UNSPECIFIED\x10\x00\x12\x08\n\x04IPV4\x10\x01\x12\x08\n\x04IPV6\x10\x02\x42\\\n\x1a\x61i.nebius.pub.vpc.v1alpha1B\tPoolProtoP\x01Z1github.com/nebius/gosdk/proto/nebius/vpc/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.vpc.v1alpha1.pool_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032ai.nebius.pub.vpc.v1alpha1B\tPoolProtoP\001Z1github.com/nebius/gosdk/proto/nebius/vpc/v1alpha1'
  _POOLSPEC.oneofs_by_name['source']._options = None
  _POOLSPEC.oneofs_by_name['source']._serialized_options = b'\272H\002\010\001'
  _POOLSPEC.fields_by_name['source_pool_id']._options = None
  _POOLSPEC.fields_by_name['source_pool_id']._serialized_options = b'\272J\001\002'
  _POOLSPEC.fields_by_name['source_scope_id']._options = None
  _POOLSPEC.fields_by_name['source_scope_id']._serialized_options = b'\272J\001\002'
  _POOLSPEC.fields_by_name['version']._options = None
  _POOLSPEC.fields_by_name['version']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _POOLCIDR.fields_by_name['cidr']._options = None
  _POOLCIDR.fields_by_name['cidr']._serialized_options = b'\272H\365\001\272\001\235\001\n\021string.valid_cidr\022.value must be a valid IP address, CIDR or mask\032Xthis == \'\' || this.matches(\'^/([0-9]|[1-9][0-9]|1[0-2][0-8])$\') || this.isIpPrefix(true)\272\001N\n\017string.ip_empty\022/value is empty, which is not a valid IP address\032\nthis != \'\'\310\001\001'
  _POOLCIDR.fields_by_name['state']._options = None
  _POOLCIDR.fields_by_name['state']._serialized_options = b'\272H\003\310\001\001'
  _POOLCIDR.fields_by_name['allowed_mask']._options = None
  _POOLCIDR.fields_by_name['allowed_mask']._serialized_options = b'\272H\n\310\001\001\"\005\030\200\001(\000'
  _globals['_POOLCIDRSTATE']._serialized_start=1169
  _globals['_POOLCIDRSTATE']._serialized_end=1236
  _globals['_IPVERSION']._serialized_start=1238
  _globals['_IPVERSION']._serialized_end=1297
  _globals['_POOL']._serialized_start=144
  _globals['_POOL']._serialized_end=322
  _globals['_POOLSPEC']._serialized_start=325
  _globals['_POOLSPEC']._serialized_end=569
  _globals['_POOLCIDR']._serialized_start=572
  _globals['_POOLCIDR']._serialized_end=971
  _globals['_POOLSTATUS']._serialized_start=974
  _globals['_POOLSTATUS']._serialized_end=1167
  _globals['_POOLSTATUS_STATE']._serialized_start=1098
  _globals['_POOLSTATUS_STATE']._serialized_end=1167
# @@protoc_insertion_point(module_scope)



# 
# Generated by the nebius.base.protos.compiler.  DO NOT EDIT!
# 

"""Auto-generated Nebius SDK package for ``nebius.registry.v1``"""

import builtins as builtins
import collections.abc as abc
import datetime as datetime
import google.protobuf.descriptor as descriptor_1
import google.protobuf.message as message_1
import google.protobuf.timestamp_pb2 as timestamp_pb2
import nebius.aio.client as client
import nebius.aio.operation as operation
import nebius.aio.request as request_1
import nebius.aio.request_kwargs as request_kwargs
import nebius.api.nebius.common.v1 as v1_1
import nebius.api.nebius.common.v1.metadata_pb2 as metadata_pb2
import nebius.api.nebius.common.v1.operation_pb2 as operation_pb2
import nebius.api.nebius.registry.v1.artifact_pb2 as artifact_pb2
import nebius.api.nebius.registry.v1.artifact_service_pb2 as artifact_service_pb2
import nebius.api.nebius.registry.v1.registry_pb2 as registry_pb2
import nebius.api.nebius.registry.v1.registry_service_pb2 as registry_service_pb2
import nebius.base.fieldmask_protobuf as fieldmask_protobuf
import nebius.base.protos.descriptor as descriptor
import nebius.base.protos.pb_classes as pb_classes
import nebius.base.protos.pb_enum as pb_enum
import nebius.base.protos.unset as unset
import nebius.base.protos.well_known as well_known_1
import typing_extensions as typing_extensions
#@ local imports here @#

# file: nebius/registry/v1/artifact.proto
class Artifact(pb_classes.Message):
    __PB2_CLASS__ = artifact_pb2.Artifact
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.registry.v1.Artifact",artifact_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
        "created_at": well_known_1.ts_mask,
        "updated_at": well_known_1.ts_mask,
    }
    
    class Status(pb_enum.Enum):
        __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.EnumDescriptor](".nebius.registry.v1.Artifact.Status",artifact_pb2.DESCRIPTOR,descriptor_1.EnumDescriptor)
        STATUS_UNSPECIFIED = 0
        ACTIVE = 1
        DELETING = 2
    
    class Type(pb_enum.Enum):
        __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.EnumDescriptor](".nebius.registry.v1.Artifact.Type",artifact_pb2.DESCRIPTOR,descriptor_1.EnumDescriptor)
        BLOB = 0
        MANIFEST = 1
        DEB_PACKAGE = 2
        MANIFEST_LIST = 3
        RELEASE_INDEX = 4
        PACKAGE_INDEX = 5
        GZIPPED_PACKAGE_INDEX = 6
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        id: "builtins.str|None|unset.UnsetType" = unset.Unset,
        name: "builtins.str|None|unset.UnsetType" = unset.Unset,
        media_type: "builtins.str|None|unset.UnsetType" = unset.Unset,
        digest: "builtins.str|None|unset.UnsetType" = unset.Unset,
        size: "builtins.int|None|unset.UnsetType" = unset.Unset,
        status: "Artifact.Status|artifact_pb2.Artifact.Status|None|unset.UnsetType" = unset.Unset,
        type: "Artifact.Type|artifact_pb2.Artifact.Type|None|unset.UnsetType" = unset.Unset,
        created_at: "timestamp_pb2.Timestamp|datetime.datetime|None|unset.UnsetType" = unset.Unset,
        updated_at: "timestamp_pb2.Timestamp|datetime.datetime|None|unset.UnsetType" = unset.Unset,
        tags: "abc.Iterable[builtins.str]|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(id, unset.UnsetType):
            self.id = id
        if not isinstance(name, unset.UnsetType):
            self.name = name
        if not isinstance(media_type, unset.UnsetType):
            self.media_type = media_type
        if not isinstance(digest, unset.UnsetType):
            self.digest = digest
        if not isinstance(size, unset.UnsetType):
            self.size = size
        if not isinstance(status, unset.UnsetType):
            self.status = status
        if not isinstance(type, unset.UnsetType):
            self.type = type
        if not isinstance(created_at, unset.UnsetType):
            self.created_at = created_at
        if not isinstance(updated_at, unset.UnsetType):
            self.updated_at = updated_at
        if not isinstance(tags, unset.UnsetType):
            self.tags = tags
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "id",
            "name",
            "media_type",
            "digest",
            "size",
            "status",
            "type",
            "created_at",
            "updated_at",
            "tags",
            "Status",
            "Type",
        ]
    
    @builtins.property
    def id(self) -> "builtins.str":
        return super()._get_field("id", explicit_presence=False,
        )
    @id.setter
    def id(self, value: "builtins.str|None") -> None:
        return super()._set_field("id",value,explicit_presence=False,
        )
    
    @builtins.property
    def name(self) -> "builtins.str":
        return super()._get_field("name", explicit_presence=False,
        )
    @name.setter
    def name(self, value: "builtins.str|None") -> None:
        return super()._set_field("name",value,explicit_presence=False,
        )
    
    @builtins.property
    def media_type(self) -> "builtins.str":
        return super()._get_field("media_type", explicit_presence=False,
        )
    @media_type.setter
    def media_type(self, value: "builtins.str|None") -> None:
        return super()._set_field("media_type",value,explicit_presence=False,
        )
    
    @builtins.property
    def digest(self) -> "builtins.str":
        return super()._get_field("digest", explicit_presence=False,
        )
    @digest.setter
    def digest(self, value: "builtins.str|None") -> None:
        return super()._set_field("digest",value,explicit_presence=False,
        )
    
    @builtins.property
    def size(self) -> "builtins.int":
        return super()._get_field("size", explicit_presence=False,
        )
    @size.setter
    def size(self, value: "builtins.int|None") -> None:
        return super()._set_field("size",value,explicit_presence=False,
        )
    
    @builtins.property
    def status(self) -> "Artifact.Status":
        return super()._get_field("status", explicit_presence=False,
        wrap=Artifact.Status,
        )
    @status.setter
    def status(self, value: "Artifact.Status|artifact_pb2.Artifact.Status|None") -> None:
        return super()._set_field("status",value,explicit_presence=False,
        )
    
    @builtins.property
    def type(self) -> "Artifact.Type":
        return super()._get_field("type", explicit_presence=False,
        wrap=Artifact.Type,
        )
    @type.setter
    def type(self, value: "Artifact.Type|artifact_pb2.Artifact.Type|None") -> None:
        return super()._set_field("type",value,explicit_presence=False,
        )
    
    @builtins.property
    def created_at(self) -> "datetime.datetime":
        return super()._get_field("created_at", explicit_presence=False,
        wrap=well_known_1.from_timestamp
        )
    @created_at.setter
    def created_at(self, value: "timestamp_pb2.Timestamp|datetime.datetime|None") -> None:
        return super()._set_field("created_at",value,explicit_presence=False,
        unwrap=well_known_1.to_timestamp
        )
    
    @builtins.property
    def updated_at(self) -> "datetime.datetime":
        return super()._get_field("updated_at", explicit_presence=False,
        wrap=well_known_1.from_timestamp
        )
    @updated_at.setter
    def updated_at(self, value: "timestamp_pb2.Timestamp|datetime.datetime|None") -> None:
        return super()._set_field("updated_at",value,explicit_presence=False,
        unwrap=well_known_1.to_timestamp
        )
    
    @builtins.property
    def tags(self) -> "abc.MutableSequence[builtins.str]":
        """
        List of tags associated with the artifact. Example: ["v1.0", "latest", "stable"].
        """
        
        return super()._get_field("tags", explicit_presence=False,
        wrap=pb_classes.Repeated,
        )
    @tags.setter
    def tags(self, value: "abc.Iterable[builtins.str]|None") -> None:
        return super()._set_field("tags",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "id":"id",
        "name":"name",
        "media_type":"media_type",
        "digest":"digest",
        "size":"size",
        "status":"status",
        "type":"type",
        "created_at":"created_at",
        "updated_at":"updated_at",
        "tags":"tags",
        "Status":"Status",
        "Type":"Type",
    }
    
# file: nebius/registry/v1/artifact_service.proto
class GetArtifactRequest(pb_classes.Message):
    __PB2_CLASS__ = artifact_service_pb2.GetArtifactRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.registry.v1.GetArtifactRequest",artifact_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        id: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(id, unset.UnsetType):
            self.id = id
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "id",
        ]
    
    @builtins.property
    def id(self) -> "builtins.str":
        return super()._get_field("id", explicit_presence=False,
        )
    @id.setter
    def id(self, value: "builtins.str|None") -> None:
        return super()._set_field("id",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "id":"id",
    }
    
class ListArtifactsRequest(pb_classes.Message):
    __PB2_CLASS__ = artifact_service_pb2.ListArtifactsRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.registry.v1.ListArtifactsRequest",artifact_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        parent_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
        page_size: "builtins.int|None|unset.UnsetType" = unset.Unset,
        page_token: "builtins.str|None|unset.UnsetType" = unset.Unset,
        filter: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(parent_id, unset.UnsetType):
            self.parent_id = parent_id
        if not isinstance(page_size, unset.UnsetType):
            self.page_size = page_size
        if not isinstance(page_token, unset.UnsetType):
            self.page_token = page_token
        if not isinstance(filter, unset.UnsetType):
            self.filter = filter
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "parent_id",
            "page_size",
            "page_token",
            "filter",
        ]
    
    @builtins.property
    def parent_id(self) -> "builtins.str":
        return super()._get_field("parent_id", explicit_presence=False,
        )
    @parent_id.setter
    def parent_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("parent_id",value,explicit_presence=False,
        )
    
    @builtins.property
    def page_size(self) -> "builtins.int":
        return super()._get_field("page_size", explicit_presence=False,
        )
    @page_size.setter
    def page_size(self, value: "builtins.int|None") -> None:
        return super()._set_field("page_size",value,explicit_presence=False,
        )
    
    @builtins.property
    def page_token(self) -> "builtins.str":
        return super()._get_field("page_token", explicit_presence=False,
        )
    @page_token.setter
    def page_token(self, value: "builtins.str|None") -> None:
        return super()._set_field("page_token",value,explicit_presence=False,
        )
    
    @builtins.property
    def filter(self) -> "builtins.str":
        return super()._get_field("filter", explicit_presence=False,
        )
    @filter.setter
    def filter(self, value: "builtins.str|None") -> None:
        return super()._set_field("filter",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "parent_id":"parent_id",
        "page_size":"page_size",
        "page_token":"page_token",
        "filter":"filter",
    }
    
class ListArtifactsResponse(pb_classes.Message):
    __PB2_CLASS__ = artifact_service_pb2.ListArtifactsResponse
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.registry.v1.ListArtifactsResponse",artifact_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        items: "abc.Iterable[Artifact]|None|unset.UnsetType" = unset.Unset,
        next_page_token: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(items, unset.UnsetType):
            self.items = items
        if not isinstance(next_page_token, unset.UnsetType):
            self.next_page_token = next_page_token
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "items",
            "next_page_token",
        ]
    
    @builtins.property
    def items(self) -> "abc.MutableSequence[Artifact]":
        return super()._get_field("items", explicit_presence=False,
        wrap=pb_classes.Repeated.with_wrap(Artifact,None,None),
        )
    @items.setter
    def items(self, value: "abc.Iterable[Artifact]|None") -> None:
        return super()._set_field("items",value,explicit_presence=False,
        )
    
    @builtins.property
    def next_page_token(self) -> "builtins.str":
        return super()._get_field("next_page_token", explicit_presence=False,
        )
    @next_page_token.setter
    def next_page_token(self, value: "builtins.str|None") -> None:
        return super()._set_field("next_page_token",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "items":"items",
        "next_page_token":"next_page_token",
    }
    
class DeleteArtifactRequest(pb_classes.Message):
    __PB2_CLASS__ = artifact_service_pb2.DeleteArtifactRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.registry.v1.DeleteArtifactRequest",artifact_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        id: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(id, unset.UnsetType):
            self.id = id
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "id",
        ]
    
    @builtins.property
    def id(self) -> "builtins.str":
        return super()._get_field("id", explicit_presence=False,
        )
    @id.setter
    def id(self, value: "builtins.str|None") -> None:
        return super()._set_field("id",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "id":"id",
    }
    

class ArtifactServiceClient(client.ClientWithOperations[v1_1.Operation,v1_1.OperationServiceClient]):
    """
    This class provides the client methods for the ``.nebius.registry.v1.ArtifactService`` service.
    
    Each method constructs a :class:`nebius.aio.request.Request` object
    that represents the in-flight RPC. The request can be awaited (async)
    or waited synchronously using its ``.wait()`` helpers.
    
    The request methods accept various parameters to configure metadata,
    timeouts, authorization, and retries. See individual method docstrings
    for details.
    
    :cvar __service_name__: The full protobuf service name.
    """
    
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.ServiceDescriptor](".nebius.registry.v1.ArtifactService",artifact_service_pb2.DESCRIPTOR,descriptor_1.ServiceDescriptor)
    """The protobuf service descriptor extraction function."""
    __service_name__ = ".nebius.registry.v1.ArtifactService"
    __operation_type__ = v1_1.Operation
    __operation_service_class__ = v1_1.OperationServiceClient
    __operation_source_method__ = "Delete"
    """The method name that can be used to fetch the address channel for the operation."""
    
    def get(self,
        request: "GetArtifactRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request_1.Request["GetArtifactRequest","Artifact"]:
        """
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.registry.v1.GetArtifactRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.registry.v1.Artifact`.
        """
        
        return super().request(
            method="Get",
            request=request,
            result_pb2_class=artifact_pb2.Artifact,
            result_wrapper=pb_classes.simple_wrapper(Artifact),
            **kwargs,
        )
    
    def list(self,
        request: "ListArtifactsRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request_1.Request["ListArtifactsRequest","ListArtifactsResponse"]:
        """
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.registry.v1.ListArtifactsRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.registry.v1.ListArtifactsResponse`.
        """
        
        return super().request(
            method="List",
            request=request,
            result_pb2_class=artifact_service_pb2.ListArtifactsResponse,
            result_wrapper=pb_classes.simple_wrapper(ListArtifactsResponse),
            **kwargs,
        )
    
    def delete(self,
        request: "DeleteArtifactRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request_1.Request["DeleteArtifactRequest","operation.Operation[v1_1.Operation]"]:
        """
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.registry.v1.DeleteArtifactRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.common.v1.Operation`.
        """
        
        return super().request(
            method="Delete",
            request=request,
            result_pb2_class=operation_pb2.Operation,
            result_wrapper=operation.Operation,
            **kwargs,
        )
    

# file: nebius/registry/v1/registry.proto
class Registry(pb_classes.Message):
    __PB2_CLASS__ = registry_pb2.Registry
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.registry.v1.Registry",registry_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        metadata: "v1_1.ResourceMetadata|metadata_pb2.ResourceMetadata|None|unset.UnsetType" = unset.Unset,
        spec: "RegistrySpec|registry_pb2.RegistrySpec|None|unset.UnsetType" = unset.Unset,
        status: "RegistryStatus|registry_pb2.RegistryStatus|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(metadata, unset.UnsetType):
            self.metadata = metadata
        if not isinstance(spec, unset.UnsetType):
            self.spec = spec
        if not isinstance(status, unset.UnsetType):
            self.status = status
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "metadata",
            "spec",
            "status",
        ]
    
    @builtins.property
    def metadata(self) -> "v1_1.ResourceMetadata":
        """
        This is metadata about the resource, such as its id, name, labels, etc.
        This contains fields that may be updated both by the end user and the system.
        """
        
        return super()._get_field("metadata", explicit_presence=False,
        wrap=v1_1.ResourceMetadata,
        )
    @metadata.setter
    def metadata(self, value: "v1_1.ResourceMetadata|metadata_pb2.ResourceMetadata|None") -> None:
        return super()._set_field("metadata",value,explicit_presence=False,
        )
    
    @builtins.property
    def spec(self) -> "RegistrySpec":
        """
        This is defined by the user and describes the desired state of system.
        Fill this in when creating or updating an object.
        """
        
        return super()._get_field("spec", explicit_presence=False,
        wrap=RegistrySpec,
        )
    @spec.setter
    def spec(self, value: "RegistrySpec|registry_pb2.RegistrySpec|None") -> None:
        return super()._set_field("spec",value,explicit_presence=False,
        )
    
    @builtins.property
    def status(self) -> "RegistryStatus":
        """
        This is filled in by the server and reports the current state of the system.
        """
        
        return super()._get_field("status", explicit_presence=False,
        wrap=RegistryStatus,
        )
    @status.setter
    def status(self, value: "RegistryStatus|registry_pb2.RegistryStatus|None") -> None:
        return super()._set_field("status",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "metadata":"metadata",
        "spec":"spec",
        "status":"status",
    }
    
class RegistrySpec(pb_classes.Message):
    __PB2_CLASS__ = registry_pb2.RegistrySpec
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.registry.v1.RegistrySpec",registry_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        description: "builtins.str|None|unset.UnsetType" = unset.Unset,
        images_count: "builtins.int|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(description, unset.UnsetType):
            self.description = description
        if not isinstance(images_count, unset.UnsetType):
            self.images_count = images_count
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "description",
            "images_count",
        ]
    
    @builtins.property
    def description(self) -> "builtins.str":
        return super()._get_field("description", explicit_presence=False,
        )
    @description.setter
    def description(self, value: "builtins.str|None") -> None:
        return super()._set_field("description",value,explicit_presence=False,
        )
    
    @builtins.property
    def images_count(self) -> "builtins.int":
        """
        Registry.Type type = 2;
        """
        
        return super()._get_field("images_count", explicit_presence=False,
        )
    @images_count.setter
    def images_count(self, value: "builtins.int|None") -> None:
        return super()._set_field("images_count",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "description":"description",
        "images_count":"images_count",
    }
    
class RegistryStatus(pb_classes.Message):
    __PB2_CLASS__ = registry_pb2.RegistryStatus
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.registry.v1.RegistryStatus",registry_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    class State(pb_enum.Enum):
        __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.EnumDescriptor](".nebius.registry.v1.RegistryStatus.State",registry_pb2.DESCRIPTOR,descriptor_1.EnumDescriptor)
        CREATING = 0
        ACTIVE = 1
        DELETING = 2
        SUSPENDED = 3
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        state: "RegistryStatus.State|registry_pb2.RegistryStatus.State|None|unset.UnsetType" = unset.Unset,
        images_count: "builtins.int|None|unset.UnsetType" = unset.Unset,
        registry_fqdn: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(state, unset.UnsetType):
            self.state = state
        if not isinstance(images_count, unset.UnsetType):
            self.images_count = images_count
        if not isinstance(registry_fqdn, unset.UnsetType):
            self.registry_fqdn = registry_fqdn
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "state",
            "images_count",
            "registry_fqdn",
            "State",
        ]
    
    @builtins.property
    def state(self) -> "RegistryStatus.State":
        return super()._get_field("state", explicit_presence=False,
        wrap=RegistryStatus.State,
        )
    @state.setter
    def state(self, value: "RegistryStatus.State|registry_pb2.RegistryStatus.State|None") -> None:
        return super()._set_field("state",value,explicit_presence=False,
        )
    
    @builtins.property
    def images_count(self) -> "builtins.int":
        return super()._get_field("images_count", explicit_presence=False,
        )
    @images_count.setter
    def images_count(self, value: "builtins.int|None") -> None:
        return super()._set_field("images_count",value,explicit_presence=False,
        )
    
    @builtins.property
    def registry_fqdn(self) -> "builtins.str":
        """
        regional fqdn "cr.eu-north1.nebius.cloud"
        """
        
        return super()._get_field("registry_fqdn", explicit_presence=False,
        )
    @registry_fqdn.setter
    def registry_fqdn(self, value: "builtins.str|None") -> None:
        return super()._set_field("registry_fqdn",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "state":"state",
        "images_count":"images_count",
        "registry_fqdn":"registry_fqdn",
        "State":"State",
    }
    
# file: nebius/registry/v1/registry_service.proto
class GetRegistryRequest(pb_classes.Message):
    __PB2_CLASS__ = registry_service_pb2.GetRegistryRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.registry.v1.GetRegistryRequest",registry_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        id: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(id, unset.UnsetType):
            self.id = id
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "id",
        ]
    
    @builtins.property
    def id(self) -> "builtins.str":
        return super()._get_field("id", explicit_presence=False,
        )
    @id.setter
    def id(self, value: "builtins.str|None") -> None:
        return super()._set_field("id",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "id":"id",
    }
    
class ListRegistriesRequest(pb_classes.Message):
    __PB2_CLASS__ = registry_service_pb2.ListRegistriesRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.registry.v1.ListRegistriesRequest",registry_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        parent_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
        page_size: "builtins.int|None|unset.UnsetType" = unset.Unset,
        page_token: "builtins.str|None|unset.UnsetType" = unset.Unset,
        filter: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(parent_id, unset.UnsetType):
            self.parent_id = parent_id
        if not isinstance(page_size, unset.UnsetType):
            self.page_size = page_size
        if not isinstance(page_token, unset.UnsetType):
            self.page_token = page_token
        if not isinstance(filter, unset.UnsetType):
            self.filter = filter
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "parent_id",
            "page_size",
            "page_token",
            "filter",
        ]
    
    @builtins.property
    def parent_id(self) -> "builtins.str":
        return super()._get_field("parent_id", explicit_presence=False,
        )
    @parent_id.setter
    def parent_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("parent_id",value,explicit_presence=False,
        )
    
    @builtins.property
    def page_size(self) -> "builtins.int":
        return super()._get_field("page_size", explicit_presence=False,
        )
    @page_size.setter
    def page_size(self, value: "builtins.int|None") -> None:
        return super()._set_field("page_size",value,explicit_presence=False,
        )
    
    @builtins.property
    def page_token(self) -> "builtins.str":
        return super()._get_field("page_token", explicit_presence=False,
        )
    @page_token.setter
    def page_token(self, value: "builtins.str|None") -> None:
        return super()._set_field("page_token",value,explicit_presence=False,
        )
    
    @builtins.property
    def filter(self) -> "builtins.str":
        return super()._get_field("filter", explicit_presence=False,
        )
    @filter.setter
    def filter(self, value: "builtins.str|None") -> None:
        return super()._set_field("filter",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "parent_id":"parent_id",
        "page_size":"page_size",
        "page_token":"page_token",
        "filter":"filter",
    }
    
class ListRegistriesResponse(pb_classes.Message):
    __PB2_CLASS__ = registry_service_pb2.ListRegistriesResponse
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.registry.v1.ListRegistriesResponse",registry_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        items: "abc.Iterable[Registry]|None|unset.UnsetType" = unset.Unset,
        next_page_token: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(items, unset.UnsetType):
            self.items = items
        if not isinstance(next_page_token, unset.UnsetType):
            self.next_page_token = next_page_token
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "items",
            "next_page_token",
        ]
    
    @builtins.property
    def items(self) -> "abc.MutableSequence[Registry]":
        return super()._get_field("items", explicit_presence=False,
        wrap=pb_classes.Repeated.with_wrap(Registry,None,None),
        )
    @items.setter
    def items(self, value: "abc.Iterable[Registry]|None") -> None:
        return super()._set_field("items",value,explicit_presence=False,
        )
    
    @builtins.property
    def next_page_token(self) -> "builtins.str":
        return super()._get_field("next_page_token", explicit_presence=False,
        )
    @next_page_token.setter
    def next_page_token(self, value: "builtins.str|None") -> None:
        return super()._set_field("next_page_token",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "items":"items",
        "next_page_token":"next_page_token",
    }
    
class CreateRegistryRequest(pb_classes.Message):
    __PB2_CLASS__ = registry_service_pb2.CreateRegistryRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.registry.v1.CreateRegistryRequest",registry_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        metadata: "v1_1.ResourceMetadata|metadata_pb2.ResourceMetadata|None|unset.UnsetType" = unset.Unset,
        spec: "RegistrySpec|registry_pb2.RegistrySpec|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(metadata, unset.UnsetType):
            self.metadata = metadata
        if not isinstance(spec, unset.UnsetType):
            self.spec = spec
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "metadata",
            "spec",
        ]
    
    @builtins.property
    def metadata(self) -> "v1_1.ResourceMetadata":
        return super()._get_field("metadata", explicit_presence=False,
        wrap=v1_1.ResourceMetadata,
        )
    @metadata.setter
    def metadata(self, value: "v1_1.ResourceMetadata|metadata_pb2.ResourceMetadata|None") -> None:
        return super()._set_field("metadata",value,explicit_presence=False,
        )
    
    @builtins.property
    def spec(self) -> "RegistrySpec":
        return super()._get_field("spec", explicit_presence=False,
        wrap=RegistrySpec,
        )
    @spec.setter
    def spec(self, value: "RegistrySpec|registry_pb2.RegistrySpec|None") -> None:
        return super()._set_field("spec",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "metadata":"metadata",
        "spec":"spec",
    }
    
class UpdateRegistryRequest(pb_classes.Message):
    __PB2_CLASS__ = registry_service_pb2.UpdateRegistryRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.registry.v1.UpdateRegistryRequest",registry_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        metadata: "v1_1.ResourceMetadata|metadata_pb2.ResourceMetadata|None|unset.UnsetType" = unset.Unset,
        spec: "RegistrySpec|registry_pb2.RegistrySpec|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(metadata, unset.UnsetType):
            self.metadata = metadata
        if not isinstance(spec, unset.UnsetType):
            self.spec = spec
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "metadata",
            "spec",
        ]
    
    @builtins.property
    def metadata(self) -> "v1_1.ResourceMetadata":
        return super()._get_field("metadata", explicit_presence=False,
        wrap=v1_1.ResourceMetadata,
        )
    @metadata.setter
    def metadata(self, value: "v1_1.ResourceMetadata|metadata_pb2.ResourceMetadata|None") -> None:
        return super()._set_field("metadata",value,explicit_presence=False,
        )
    
    @builtins.property
    def spec(self) -> "RegistrySpec":
        return super()._get_field("spec", explicit_presence=False,
        wrap=RegistrySpec,
        )
    @spec.setter
    def spec(self, value: "RegistrySpec|registry_pb2.RegistrySpec|None") -> None:
        return super()._set_field("spec",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "metadata":"metadata",
        "spec":"spec",
    }
    
class DeleteRegistryRequest(pb_classes.Message):
    __PB2_CLASS__ = registry_service_pb2.DeleteRegistryRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.registry.v1.DeleteRegistryRequest",registry_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        id: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(id, unset.UnsetType):
            self.id = id
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "id",
        ]
    
    @builtins.property
    def id(self) -> "builtins.str":
        return super()._get_field("id", explicit_presence=False,
        )
    @id.setter
    def id(self, value: "builtins.str|None") -> None:
        return super()._set_field("id",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "id":"id",
    }
    

class RegistryServiceClient(client.ClientWithOperations[v1_1.Operation,v1_1.OperationServiceClient]):
    """
    This class provides the client methods for the ``.nebius.registry.v1.RegistryService`` service.
    
    Each method constructs a :class:`nebius.aio.request.Request` object
    that represents the in-flight RPC. The request can be awaited (async)
    or waited synchronously using its ``.wait()`` helpers.
    
    The request methods accept various parameters to configure metadata,
    timeouts, authorization, and retries. See individual method docstrings
    for details.
    
    :cvar __service_name__: The full protobuf service name.
    """
    
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.ServiceDescriptor](".nebius.registry.v1.RegistryService",registry_service_pb2.DESCRIPTOR,descriptor_1.ServiceDescriptor)
    """The protobuf service descriptor extraction function."""
    __service_name__ = ".nebius.registry.v1.RegistryService"
    __operation_type__ = v1_1.Operation
    __operation_service_class__ = v1_1.OperationServiceClient
    __operation_source_method__ = "Create"
    """The method name that can be used to fetch the address channel for the operation."""
    
    def get(self,
        request: "GetRegistryRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request_1.Request["GetRegistryRequest","Registry"]:
        """
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.registry.v1.GetRegistryRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.registry.v1.Registry`.
        """
        
        return super().request(
            method="Get",
            request=request,
            result_pb2_class=registry_pb2.Registry,
            result_wrapper=pb_classes.simple_wrapper(Registry),
            **kwargs,
        )
    
    def list(self,
        request: "ListRegistriesRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request_1.Request["ListRegistriesRequest","ListRegistriesResponse"]:
        """
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.registry.v1.ListRegistriesRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.registry.v1.ListRegistriesResponse`.
        """
        
        return super().request(
            method="List",
            request=request,
            result_pb2_class=registry_service_pb2.ListRegistriesResponse,
            result_wrapper=pb_classes.simple_wrapper(ListRegistriesResponse),
            **kwargs,
        )
    
    def create(self,
        request: "CreateRegistryRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request_1.Request["CreateRegistryRequest","operation.Operation[v1_1.Operation]"]:
        """
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.registry.v1.CreateRegistryRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.common.v1.Operation`.
        """
        
        return super().request(
            method="Create",
            request=request,
            result_pb2_class=operation_pb2.Operation,
            result_wrapper=operation.Operation,
            **kwargs,
        )
    
    def update(self,
        request: "UpdateRegistryRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request_1.Request["UpdateRegistryRequest","operation.Operation[v1_1.Operation]"]:
        """
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.registry.v1.UpdateRegistryRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.common.v1.Operation`.
        """
        
        kwargs['metadata'] = fieldmask_protobuf.ensure_reset_mask_in_metadata(request, kwargs.get('metadata', None))
        return super().request(
            method="Update",
            request=request,
            result_pb2_class=operation_pb2.Operation,
            result_wrapper=operation.Operation,
            **kwargs,
        )
    
    def delete(self,
        request: "DeleteRegistryRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request_1.Request["DeleteRegistryRequest","operation.Operation[v1_1.Operation]"]:
        """
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.registry.v1.DeleteRegistryRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.common.v1.Operation`.
        """
        
        return super().request(
            method="Delete",
            request=request,
            result_pb2_class=operation_pb2.Operation,
            result_wrapper=operation.Operation,
            **kwargs,
        )
    

__all__ = [
    #@ local import names here @#
    "Artifact",
    "GetArtifactRequest",
    "ListArtifactsRequest",
    "ListArtifactsResponse",
    "DeleteArtifactRequest",
    "ArtifactServiceClient",
    "Registry",
    "RegistrySpec",
    "RegistryStatus",
    "GetRegistryRequest",
    "ListRegistriesRequest",
    "ListRegistriesResponse",
    "CreateRegistryRequest",
    "UpdateRegistryRequest",
    "DeleteRegistryRequest",
    "RegistryServiceClient",
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/storage/v1/bucket_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.storage.v1 import bucket_pb2 as nebius_dot_storage_dot_v1_dot_bucket__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&nebius/storage/v1/bucket_service.proto\x12\x11nebius.storage.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a\x1enebius/storage/v1/bucket.proto\"0\n\x10GetBucketRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02idJ\x04\x08\x02\x10\x03\"W\n\x16GetBucketByNameRequest\x12\x1b\n\tparent_id\x18\x01 \x01(\tR\x08parentId\x12\x1a\n\x04name\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04nameJ\x04\x08\x03\x10\x04\"\x96\x01\n\x13\x43reateBucketRequest\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x37\n\x04spec\x18\x02 \x01(\x0b\x32\x1d.nebius.storage.v1.BucketSpecB\x04\xbaJ\x01\x07R\x04spec\"\x98\x01\n\x13UpdateBucketRequest\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x39\n\x04spec\x18\x02 \x01(\x0b\x32\x1d.nebius.storage.v1.BucketSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\"\xa4\x01\n\x13\x44\x65leteBucketRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\x12\x37\n\x08purge_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x07purgeAt\x12-\n\x03ttl\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x03ttlB\x07\n\x05purgeJ\x04\x08\x02\x10\x03\",\n\x12PurgeBucketRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"/\n\x15UndeleteBucketRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\x93\x01\n\x12ListBucketsRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilterJ\x04\x08\x05\x10\x06\"n\n\x13ListBucketsResponse\x12/\n\x05items\x18\x01 \x03(\x0b\x32\x19.nebius.storage.v1.BucketR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\x9d\x05\n\rBucketService\x12\x45\n\x03Get\x12#.nebius.storage.v1.GetBucketRequest\x1a\x19.nebius.storage.v1.Bucket\x12Q\n\tGetByName\x12).nebius.storage.v1.GetBucketByNameRequest\x1a\x19.nebius.storage.v1.Bucket\x12U\n\x04List\x12%.nebius.storage.v1.ListBucketsRequest\x1a&.nebius.storage.v1.ListBucketsResponse\x12M\n\x06\x43reate\x12&.nebius.storage.v1.CreateBucketRequest\x1a\x1b.nebius.common.v1.Operation\x12M\n\x06Update\x12&.nebius.storage.v1.UpdateBucketRequest\x1a\x1b.nebius.common.v1.Operation\x12M\n\x06\x44\x65lete\x12&.nebius.storage.v1.DeleteBucketRequest\x1a\x1b.nebius.common.v1.Operation\x12K\n\x05Purge\x12%.nebius.storage.v1.PurgeBucketRequest\x1a\x1b.nebius.common.v1.Operation\x12Q\n\x08Undelete\x12(.nebius.storage.v1.UndeleteBucketRequest\x1a\x1b.nebius.common.v1.Operation\x1a\x0e\xbaJ\x0b\x63pl.storageBa\n\x18\x61i.nebius.pub.storage.v1B\x12\x42ucketServiceProtoP\x01Z/github.com/nebius/gosdk/proto/nebius/storage/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.storage.v1.bucket_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030ai.nebius.pub.storage.v1B\022BucketServiceProtoP\001Z/github.com/nebius/gosdk/proto/nebius/storage/v1'
  _GETBUCKETREQUEST.fields_by_name['id']._options = None
  _GETBUCKETREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _GETBUCKETBYNAMEREQUEST.fields_by_name['name']._options = None
  _GETBUCKETBYNAMEREQUEST.fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _CREATEBUCKETREQUEST.fields_by_name['metadata']._options = None
  _CREATEBUCKETREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _CREATEBUCKETREQUEST.fields_by_name['spec']._options = None
  _CREATEBUCKETREQUEST.fields_by_name['spec']._serialized_options = b'\272J\001\007'
  _UPDATEBUCKETREQUEST.fields_by_name['metadata']._options = None
  _UPDATEBUCKETREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _UPDATEBUCKETREQUEST.fields_by_name['spec']._options = None
  _UPDATEBUCKETREQUEST.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _DELETEBUCKETREQUEST.fields_by_name['id']._options = None
  _DELETEBUCKETREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _PURGEBUCKETREQUEST.fields_by_name['id']._options = None
  _PURGEBUCKETREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _UNDELETEBUCKETREQUEST.fields_by_name['id']._options = None
  _UNDELETEBUCKETREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _LISTBUCKETSREQUEST.fields_by_name['parent_id']._options = None
  _LISTBUCKETSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _BUCKETSERVICE._options = None
  _BUCKETSERVICE._serialized_options = b'\272J\013cpl.storage'
  _globals['_GETBUCKETREQUEST']._serialized_start=280
  _globals['_GETBUCKETREQUEST']._serialized_end=328
  _globals['_GETBUCKETBYNAMEREQUEST']._serialized_start=330
  _globals['_GETBUCKETBYNAMEREQUEST']._serialized_end=417
  _globals['_CREATEBUCKETREQUEST']._serialized_start=420
  _globals['_CREATEBUCKETREQUEST']._serialized_end=570
  _globals['_UPDATEBUCKETREQUEST']._serialized_start=573
  _globals['_UPDATEBUCKETREQUEST']._serialized_end=725
  _globals['_DELETEBUCKETREQUEST']._serialized_start=728
  _globals['_DELETEBUCKETREQUEST']._serialized_end=892
  _globals['_PURGEBUCKETREQUEST']._serialized_start=894
  _globals['_PURGEBUCKETREQUEST']._serialized_end=938
  _globals['_UNDELETEBUCKETREQUEST']._serialized_start=940
  _globals['_UNDELETEBUCKETREQUEST']._serialized_end=987
  _globals['_LISTBUCKETSREQUEST']._serialized_start=990
  _globals['_LISTBUCKETSREQUEST']._serialized_end=1137
  _globals['_LISTBUCKETSRESPONSE']._serialized_start=1139
  _globals['_LISTBUCKETSRESPONSE']._serialized_end=1249
  _globals['_BUCKETSERVICE']._serialized_start=1252
  _globals['_BUCKETSERVICE']._serialized_end=1921
# @@protoc_insertion_point(module_scope)



"""Type alias for deferred client channel objects.

Examples
--------

Used in deferred token bearer implementations::

    from nebius.aio.token.deferred_channel import DeferredChannel
    from nebius.aio.abc import ClientChannelInterface
    from nebius.aio.token.service_account import ServiceAccountBearer
    from asyncio import Future

    chan: DeferredChannel = Future[ClientChannelInterface]()
    bearer = ServiceAccountBearer(..., channel=chan)

    sdk = SDK(credentials=bearer)
    chan.set_result(sdk)
"""

from collections.abc import Awaitable

from nebius.aio.abc import ClientChannelInterface

DeferredChannel = Awaitable[ClientChannelInterface]
"""Deferred client channel type.

Used in deferred token bearer implementations::

    from nebius.aio.token.deferred_channel import DeferredChannel
    from nebius.aio.abc import ClientChannelInterface
    from nebius.aio.token.service_account import ServiceAccountBearer
    from asyncio import Future

    chan: DeferredChannel = Future[ClientChannelInterface]()
    bearer = ServiceAccountBearer(..., channel=chan)

    sdk = SDK(credentials=bearer)
    chan.set_result(sdk)
"""



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/common/error/v1alpha1/error.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.error.v1alpha1 import common_errors_pb2 as nebius_dot_common_dot_error_dot_v1alpha1_dot_common__errors__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(nebius/common/error/v1alpha1/error.proto\x12\x1cnebius.common.error.v1alpha1\x1a\x18nebius/annotations.proto\x1a\x30nebius/common/error/v1alpha1/common_errors.proto\"\xf2\t\n\x0cServiceError\x12\x18\n\x07service\x18\x01 \x01(\tR\x07service\x12\x12\n\x04\x63ode\x18\x02 \x01(\tR\x04\x63ode\x12K\n\x0b\x62\x61\x64_request\x18\x64 \x01(\x0b\x32(.nebius.common.error.v1alpha1.BadRequestH\x00R\nbadRequest\x12^\n\x12\x62\x61\x64_resource_state\x18n \x01(\x0b\x32..nebius.common.error.v1alpha1.BadResourceStateH\x00R\x10\x62\x61\x64ResourceState\x12^\n\x12resource_not_found\x18o \x01(\x0b\x32..nebius.common.error.v1alpha1.ResourceNotFoundH\x00R\x10resourceNotFound\x12m\n\x17resource_already_exists\x18p \x01(\x0b\x32\x33.nebius.common.error.v1alpha1.ResourceAlreadyExistsH\x00R\x15resourceAlreadyExists\x12L\n\x0cout_of_range\x18q \x01(\x0b\x32(.nebius.common.error.v1alpha1.OutOfRangeH\x00R\noutOfRange\x12]\n\x11permission_denied\x18x \x01(\x0b\x32..nebius.common.error.v1alpha1.PermissionDeniedH\x00R\x10permissionDenied\x12^\n\x11resource_conflict\x18\x82\x01 \x01(\x0b\x32..nebius.common.error.v1alpha1.ResourceConflictH\x00R\x10resourceConflict\x12^\n\x11operation_aborted\x18\x83\x01 \x01(\x0b\x32..nebius.common.error.v1alpha1.OperationAbortedH\x00R\x10operationAborted\x12\\\n\x11too_many_requests\x18\x8c\x01 \x01(\x0b\x32-.nebius.common.error.v1alpha1.TooManyRequestsH\x00R\x0ftooManyRequests\x12R\n\rquota_failure\x18\x8d\x01 \x01(\x0b\x32*.nebius.common.error.v1alpha1.QuotaFailureH\x00R\x0cquotaFailure\x12U\n\x0einternal_error\x18\xe7\x07 \x01(\x0b\x32+.nebius.common.error.v1alpha1.InternalErrorH\x00R\rinternalError\x12S\n\nretry_type\x18\x1e \x01(\x0e\x32\x34.nebius.common.error.v1alpha1.ServiceError.RetryTypeR\tretryType\"E\n\tRetryType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04\x43\x41LL\x10\x01\x12\x10\n\x0cUNIT_OF_WORK\x10\x02\x12\x0b\n\x07NOTHING\x10\x03:\x1b\x18\x01\xd2J\x16\x12\x14migrate to common/v1B\t\n\x07\x64\x65tailsB\x8b\x01\n#ai.nebius.pub.common.error.v1alpha1B\nErrorProtoP\x01Z:github.com/nebius/gosdk/proto/nebius/common/error/v1alpha1\xb8\x01\x01\xd2J\x16\x12\x14migrate to common/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.common.error.v1alpha1.error_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#ai.nebius.pub.common.error.v1alpha1B\nErrorProtoP\001Z:github.com/nebius/gosdk/proto/nebius/common/error/v1alpha1\270\001\001\322J\026\022\024migrate to common/v1'
  _SERVICEERROR._options = None
  _SERVICEERROR._serialized_options = b'\030\001\322J\026\022\024migrate to common/v1'
  _globals['_SERVICEERROR']._serialized_start=151
  _globals['_SERVICEERROR']._serialized_end=1417
  _globals['_SERVICEERROR_RETRYTYPE']._serialized_start=1308
  _globals['_SERVICEERROR_RETRYTYPE']._serialized_end=1377
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/mk8s/v1/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cnebius/mk8s/v1/cluster.proto\x12\x0enebius.mk8s.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\"\xb1\x01\n\x07\x43luster\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12/\n\x04spec\x18\x02 \x01(\x0b\x32\x1b.nebius.mk8s.v1.ClusterSpecR\x04spec\x12\x35\n\x06status\x18\x03 \x01(\x0b\x32\x1d.nebius.mk8s.v1.ClusterStatusR\x06status\"\xa0\x01\n\x0b\x43lusterSpec\x12M\n\rcontrol_plane\x18\x02 \x01(\x0b\x32 .nebius.mk8s.v1.ControlPlaneSpecB\x06\xbaH\x03\xc8\x01\x01R\x0c\x63ontrolPlane\x12\x42\n\x0ckube_network\x18\x03 \x01(\x0b\x32\x1f.nebius.mk8s.v1.KubeNetworkSpecR\x0bkubeNetwork\"\xeb\x01\n\x10\x43ontrolPlaneSpec\x12,\n\x07version\x18\x01 \x01(\tB\x12\xbaH\x0fr\r2\x0b|^\\d\\.\\d\\d$R\x07version\x12\'\n\tsubnet_id\x18\x02 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\x08subnetId\x12G\n\tendpoints\x18\x03 \x01(\x0b\x32).nebius.mk8s.v1.ControlPlaneEndpointsSpecR\tendpoints\x12\x37\n\x11\x65tcd_cluster_size\x18\x04 \x01(\x03\x42\x0b\xbaH\x08\"\x06\x30\x00\x30\x01\x30\x03R\x0f\x65tcdClusterSize\"n\n\x19\x43ontrolPlaneEndpointsSpec\x12Q\n\x0fpublic_endpoint\x18\x01 \x01(\x0b\x32\".nebius.mk8s.v1.PublicEndpointSpecB\x04\xbaJ\x01\x06R\x0epublicEndpoint\"\x14\n\x12PublicEndpointSpec\"\xd1\x01\n\x0fKubeNetworkSpec\x12\xbd\x01\n\rservice_cidrs\x18\x01 \x03(\tB\x97\x01\xbaH\x8f\x01\xba\x01\x86\x01\n\x11string.valid_cidr\x12?value must be a CIDR block or prefix length from \"/12\" to \"/28\"\x1a\x30this.all(x, x.matches(\'^(.*)/(1[2-9]|2[0-8])$\'))\x92\x01\x02\x10\x01\xbaJ\x01\x02R\x0cserviceCidrs\"\x82\x02\n\rClusterStatus\x12\x39\n\x05state\x18\x01 \x01(\x0e\x32#.nebius.mk8s.v1.ClusterStatus.StateR\x05state\x12G\n\rcontrol_plane\x18\x02 \x01(\x0b\x32\".nebius.mk8s.v1.ControlPlaneStatusR\x0c\x63ontrolPlane\x12 \n\x0breconciling\x18\x64 \x01(\x08R\x0breconciling\"K\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x10\n\x0cPROVISIONING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\"\xe1\x01\n\x12\x43ontrolPlaneStatus\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12I\n\tendpoints\x18\x02 \x01(\x0b\x32+.nebius.mk8s.v1.ControlPlaneStatusEndpointsR\tendpoints\x12*\n\x11\x65tcd_cluster_size\x18\x03 \x01(\x03R\x0f\x65tcdClusterSize\x12:\n\x04\x61uth\x18\x64 \x01(\x0b\x32&.nebius.mk8s.v1.ControlPlaneStatusAuthR\x04\x61uth\"q\n\x1b\x43ontrolPlaneStatusEndpoints\x12\'\n\x0fpublic_endpoint\x18\x01 \x01(\tR\x0epublicEndpoint\x12)\n\x10private_endpoint\x18\x02 \x01(\tR\x0fprivateEndpoint\"N\n\x16\x43ontrolPlaneStatusAuth\x12\x34\n\x16\x63luster_ca_certificate\x18\x01 \x01(\tR\x14\x63lusterCaCertificateBU\n\x15\x61i.nebius.pub.mk8s.v1B\x0c\x43lusterProtoP\x01Z,github.com/nebius/gosdk/proto/nebius/mk8s/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.mk8s.v1.cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025ai.nebius.pub.mk8s.v1B\014ClusterProtoP\001Z,github.com/nebius/gosdk/proto/nebius/mk8s/v1'
  _CLUSTERSPEC.fields_by_name['control_plane']._options = None
  _CLUSTERSPEC.fields_by_name['control_plane']._serialized_options = b'\272H\003\310\001\001'
  _CONTROLPLANESPEC.fields_by_name['version']._options = None
  _CONTROLPLANESPEC.fields_by_name['version']._serialized_options = b'\272H\017r\r2\013|^\\d\\.\\d\\d$'
  _CONTROLPLANESPEC.fields_by_name['subnet_id']._options = None
  _CONTROLPLANESPEC.fields_by_name['subnet_id']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _CONTROLPLANESPEC.fields_by_name['etcd_cluster_size']._options = None
  _CONTROLPLANESPEC.fields_by_name['etcd_cluster_size']._serialized_options = b'\272H\010\"\0060\0000\0010\003'
  _CONTROLPLANEENDPOINTSSPEC.fields_by_name['public_endpoint']._options = None
  _CONTROLPLANEENDPOINTSSPEC.fields_by_name['public_endpoint']._serialized_options = b'\272J\001\006'
  _KUBENETWORKSPEC.fields_by_name['service_cidrs']._options = None
  _KUBENETWORKSPEC.fields_by_name['service_cidrs']._serialized_options = b'\272H\217\001\272\001\206\001\n\021string.valid_cidr\022?value must be a CIDR block or prefix length from \"/12\" to \"/28\"\0320this.all(x, x.matches(\'^(.*)/(1[2-9]|2[0-8])$\'))\222\001\002\020\001\272J\001\002'
  _globals['_CLUSTER']._serialized_start=137
  _globals['_CLUSTER']._serialized_end=314
  _globals['_CLUSTERSPEC']._serialized_start=317
  _globals['_CLUSTERSPEC']._serialized_end=477
  _globals['_CONTROLPLANESPEC']._serialized_start=480
  _globals['_CONTROLPLANESPEC']._serialized_end=715
  _globals['_CONTROLPLANEENDPOINTSSPEC']._serialized_start=717
  _globals['_CONTROLPLANEENDPOINTSSPEC']._serialized_end=827
  _globals['_PUBLICENDPOINTSPEC']._serialized_start=829
  _globals['_PUBLICENDPOINTSPEC']._serialized_end=849
  _globals['_KUBENETWORKSPEC']._serialized_start=852
  _globals['_KUBENETWORKSPEC']._serialized_end=1061
  _globals['_CLUSTERSTATUS']._serialized_start=1064
  _globals['_CLUSTERSTATUS']._serialized_end=1322
  _globals['_CLUSTERSTATUS_STATE']._serialized_start=1247
  _globals['_CLUSTERSTATUS_STATE']._serialized_end=1322
  _globals['_CONTROLPLANESTATUS']._serialized_start=1325
  _globals['_CONTROLPLANESTATUS']._serialized_end=1550
  _globals['_CONTROLPLANESTATUSENDPOINTS']._serialized_start=1552
  _globals['_CONTROLPLANESTATUSENDPOINTS']._serialized_end=1665
  _globals['_CONTROLPLANESTATUSAUTH']._serialized_start=1667
  _globals['_CONTROLPLANESTATUSAUTH']._serialized_end=1745
# @@protoc_insertion_point(module_scope)
